assert

package
v2.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 24, 2026 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func So

func So(t testingT, actual any, assertion Assertion, expected ...any)

Types

type Assertion

type Assertion func(actual any, expected ...any) error

Directories

Path Synopsis
Package better provides the same assertions as the should package, but the error returned in failure conditions results in a call to *testing.T.Fatal(), halting the currently running test.
Package better provides the same assertions as the should package, but the error returned in failure conditions results in a call to *testing.T.Fatal(), halting the currently running test.
internal/go-diff/diffmatchpatch
Package diffmatchpatch offers robust algorithms to perform the operations required for synchronizing plain text.
Package diffmatchpatch offers robust algorithms to perform the operations required for synchronizing plain text.

Jump to