Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Options singleton
Options provides the sole entrypoint to the option functions provided by this package.
Functions ¶
func Run ¶
Run accepts a fixture with Test* methods and optional setup/teardown methods and executes the suite. Fixtures must be struct types which embeds a *gunit.Fixture. Assuming a fixture struct with test methods 'Test1' and 'Test2' execution would proceed as follows:
- fixture.SetupSuite()
- fixture.Setup()
- fixture.Test1()
- fixture.Teardown()
- fixture.Setup()
- fixture.Test2()
- fixture.Teardown()
- fixture.TeardownSuite()
The methods provided by Options may be supplied to this function to tweak the execution.
Types ¶
type Fixture ¶
type Fixture struct{ TestingT }
type Option ¶
type Option func(*config)
Option is a function that modifies a config. See Options for provided behaviors.
type TestingT ¶
type TestingT interface {
Cleanup(func())
Context() context.Context
Error(args ...any)
Errorf(format string, args ...any)
Fail()
FailNow()
Failed() bool
Fatal(args ...any)
Fatalf(format string, args ...any)
Helper()
Log(args ...any)
Logf(format string, args ...any)
Name() string
Output() io.Writer
Setenv(key, value string)
Skip(args ...any)
SkipNow()
Skipf(format string, args ...any)
Skipped() bool
TempDir() string
}
Directories
¶
| Path | Synopsis |
|---|---|
|
better
Package better provides the same assertions as the should package, but the error returned in failure conditions results in a call to *testing.T.Fatal(), halting the currently running test.
|
Package better provides the same assertions as the should package, but the error returned in failure conditions results in a call to *testing.T.Fatal(), halting the currently running test. |
|
should/internal/go-diff/diffmatchpatch
Package diffmatchpatch offers robust algorithms to perform the operations required for synchronizing plain text.
|
Package diffmatchpatch offers robust algorithms to perform the operations required for synchronizing plain text. |
Click to show internal directories.
Click to hide internal directories.